package at.ac.uibk.gitsearch.repository.jpa;

import at.ac.uibk.gitsearch.domain.Authority;
import at.ac.uibk.gitsearch.domain.User;
import java.util.List;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;

/**
 * Spring Data JPA repository for the {@link Authority} entity.
 */
public interface AuthorityRepository extends JpaRepository<Authority, String> {
    @Query("DELETE FROM Authority auth WHERE not exists (SELECT u FROM User u WHERE auth member u.authorities)")
    @Modifying
    void deleteUnusedAuthorities();

    /**
     * mainly for test purposes only. Returns all authentications that are used by some user
     * @return
     */
    @Query("SELECT DISTINCT u.authorities  FROM User u ")
    List<Authority> getUsedAuthorities();

    List<Authority> findAll();

    @Query("SELECT u FROM User u JOIN u.authorities auth WHERE auth.name = :authority")
    List<User> findAllUsersWithAuthority(@Param("authority") String authority);
}
