package at.ac.uibk.gitsearch.web.rest;

import at.ac.uibk.gitsearch.security.jwt.TokenProvider;
import at.ac.uibk.gitsearch.service.MailService;
import at.ac.uibk.gitsearch.service.UserService;
import at.ac.uibk.gitsearch.service.dto.MessageDTO;
import java.util.Optional;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * REST controller for various tests that can be initiated by the user.
 */
@RestController
@RequestMapping("/api")
public class CheckResource {

    private final Logger log = LoggerFactory.getLogger(CheckResource.class);

    private final MailService mailService;

    @SuppressWarnings({ "unused", "PMD.SingularField" })
    private final TokenProvider tokenProvider;

    private final UserService userService;

    public CheckResource(MailService mailService, TokenProvider tokenProvider, UserService userService) {
        this.mailService = mailService;
        this.tokenProvider = tokenProvider;
        this.userService = userService;
    }

    /**
     * {@code Get  /triggerInfoMail} : Triggers the info mail for the current user.
     */
    @GetMapping("/triggerInfoMail")
    public MessageDTO triggerInfoMail() {
        Optional<at.ac.uibk.gitsearch.domain.User> uo = userService.getUserWithAuthorities();

        if (uo.isEmpty()) {
            log.debug("unknown user for triggerInfoMail");
            throw new AccountResource.AccountResourceException("User could not be found");
        }
        boolean wasSent = mailService.sendInfoMail(uo.get(), true/* even if no content */);
        return new MessageDTO(
            wasSent
                ? "Mail successfully sent to " + uo.get().getEmail()
                : "no relevant content found (or potential mailing problems). No Mail sent to " + uo.get().getEmail()
        );
    }
}
